@@ -43,6 +43,9 @@ import nslsii.detectors.zebra
 print("import: 'nslsii.devices'")
 import nslsii.devices
 
+print("import: 'nslsii.iocs.eps_two_state_ioc_sim'")
+import nslsii.iocs.eps_two_state_ioc_sim
+
 print("import: 'nslsii.temperature_controllers'")
 import nslsii.temperature_controllers
 
